@@ -49,6 +49,7 @@
 #include "htmlimage.h"
 #include "htmlrule.h"
 #include "htmltable.h"
+#include "htmlselection.h"
 
 #include "menubar.h"
 #include "gtkhtml.h"
@@ -169,6 +170,9 @@ insert_table (GtkHTMLControlData *cd)
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
+	if (cd->html->engine && cd->html->engine->selection)
+		html_engine_unselect_all (cd->html->engine);
+
 	html_engine_insert_table_1_1 (cd->html->engine);
 	if (html_engine_get_table (cd->html->engine)) {
 		html_engine_table_set_cols (cd->html->engine, 3);
@@ -355,7 +359,7 @@ format_page_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cnam
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"),
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Format"),
 								     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
@@ -373,7 +377,7 @@ format_text_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cnam
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"),
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Format"),
 								     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
@@ -391,7 +395,7 @@ format_paragraph_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"),
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Format"),
 								     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
@@ -487,8 +491,8 @@ static struct {
 	const gchar *command;
 	const gchar *verb;
 } command_assoc[] = {
-	{"size-minus-two", "FontSizeNegTwo"},
-	{"size-minus-one", "FontSizeNegOne"},
+	{"size-minus-2", "FontSizeNegTwo"},
+	{"size-minus-1", "FontSizeNegOne"},
 	{"size-plus-0", "FontSizeZero"},
 	{"size-plus-1", "FontSizeOne"},
 	{"size-plus-2", "FontSizeTwo"},
@@ -579,6 +583,24 @@ menubar_update_format (GtkHTMLControlData *cd)
 
 		bonobo_ui_component_set_prop (uic, "/commands/InsertImage",
 					      "sensitive", sensitive, &ev);
+		bonobo_ui_component_set_prop (uic, "/commands/FormatPage",
+					      "sensitive", sensitive, &ev);
+		bonobo_ui_component_set_prop (uic, "/commands/FormatText",
+					      "sensitive", sensitive, &ev);
+		bonobo_ui_component_set_prop (uic, "/commands/FontSizeNegTwo",
+					      "sensitive", sensitive, &ev);
+		bonobo_ui_component_set_prop (uic, "/commands/FontSizeNegOne",
+					      "sensitive", sensitive, &ev);
+		bonobo_ui_component_set_prop (uic, "/commands/FontSizeZero",
+					      "sensitive", sensitive, &ev);
+		bonobo_ui_component_set_prop (uic, "/commands/FontSizeOne",
+					      "sensitive", sensitive, &ev);
+		bonobo_ui_component_set_prop (uic, "/commands/FontSizeTwo",
+					      "sensitive", sensitive, &ev);
+		bonobo_ui_component_set_prop (uic, "/commands/FontSizeThree",
+					      "sensitive", sensitive, &ev);
+		bonobo_ui_component_set_prop (uic, "/commands/FontSizeFour",
+					      "sensitive", sensitive, &ev);
 		bonobo_ui_component_set_prop (uic, "/commands/InsertLink",
 					      "sensitive", sensitive, &ev);
 		bonobo_ui_component_set_prop (uic, "/commands/InsertRule",
@@ -620,7 +642,7 @@ menubar_update_format (GtkHTMLControlData *cd)
 					      "sensitive", sensitive, &ev);
 		bonobo_ui_component_set_prop (uic, "/commands/FormatStrikeout",
 					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/FormatPlain",
+		bonobo_ui_component_set_prop (uic, "/commands/FormatFixed",
 					      "sensitive", sensitive, &ev);
 
 		bonobo_ui_component_set_prop (uic, "/commands/HeadingH1",
